import {
  Metadata,
} from '@zeedhi/core';
import {
  SelectMultiple, DateRange, Modal, ModalService, Tabs,
} from '@zeedhi/common';
import { IterableComponentRender } from '@zeedhi/teknisa-components-common';

export class Fm00011000NaoConformidadesController {
    private conformidadesGerais!: Modal;

    private conformidadesPrincipais!: Modal;

    public async criarModais() {
        this.conformidadesGerais = await ModalService.createFromJsonPost('', { jsonPath: 'fm_00011_000_analise_nao_conformidade/modal/fm_00011_001_filtros_gerais' });
        this.conformidadesPrincipais = await ModalService.createFromJsonPost('', { jsonPath: 'fm_00011_000_analise_nao_conformidade/modal/fm_00011_002_filtros_principais' });
    }

    public destruirModais() {
        this.conformidadesGerais?.destroy();
        this.conformidadesPrincipais?.destroy();
    }

    public async fecharModalGerais() {
        this.conformidadesGerais.hide();
    }

    public async fecharModalPrincipais() {
        this.conformidadesPrincipais.hide();
    }

    public abrirModal() {
        const arrayTabs = Metadata.getInstance<Tabs>('tabs-nao-conformidades');

        if (arrayTabs.tabs[arrayTabs.activeTab].name === 'tab-gerais') {
            this.conformidadesGerais.show();
        } else {
            this.conformidadesPrincipais.show();
        }
    }

    public setFilterConformidadesGerais() {
        const card = Metadata.getInstance<IterableComponentRender>('iterable-cards-nao-conformidades-gerais');
        card.datasource.setFilter({
            NRLOCALCLIENTE: Metadata.getInstance<SelectMultiple>('filtro-local').value,
            NRTIPOLOCALCLI: Metadata.getInstance<SelectMultiple>('filtroTipoLocal').value,
            CDOPERADOR: Metadata.getInstance<SelectMultiple>('filtroUsuario').value,
            CDOPERADORPAI: Metadata.getInstance<SelectMultiple>('filtroGestor').value,
            filtroDataRange: Metadata.getInstance<DateRange>('data').value,
        });
        this.fecharModalGerais();
    }

    public limparFiltrosGerais() {
        const card = Metadata.getInstance<IterableComponentRender>('iterable-cards-nao-conformidades-gerais');

        Metadata.getInstance<SelectMultiple>('filtro-local').value = null;
        Metadata.getInstance<SelectMultiple>('filtroTipoLocal').value = null;
        Metadata.getInstance<SelectMultiple>('filtroUsuario').value = null;
        Metadata.getInstance<SelectMultiple>('filtroGestor').value = null;
        Metadata.getInstance<DateRange>('data').value = null;

        card.datasource.get();
    }

    public limparFiltroPrincipais() {
        const card = Metadata.getInstance<IterableComponentRender>('iterable-cards-nao-conformidades-principais');

        Metadata.getInstance<DateRange>('filtroDataRange').value = null;
        card.datasource.get();
    }

    public setFilterConformidadesPrincipais() {
        const card = Metadata.getInstance<IterableComponentRender>('iterable-cards-nao-conformidades-principais');
        card.datasource.setFilter({
            filtroDataRange: Metadata.getInstance<DateRange>('filtroDataRange').value,
        });
        this.fecharModalPrincipais();
    }
}
